Constraints class

Constructors

Constraints({required NetworkType networkType, bool? requiresBatteryNotLow, bool? requiresCharging, bool? requiresDeviceIdle, bool? requiresStorageNotLow})

Properties

hashCode int
The hash code for this object.
no setterinherited
networkType NetworkType
final
requiresBatteryNotLow bool?
final
requiresCharging bool?
final
requiresDeviceIdle bool?
final
requiresStorageNotLow bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited